@@ -1,9 +1,9 @@
 package Text::ANSITable;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-19'; # DATE
+our $DATE = '2021-08-08'; # DATE
 our $DIST = 'Text-ANSITable'; # DIST
-our $VERSION = '0.602'; # VERSION
+our $VERSION = '0.603'; # VERSION
 
 use 5.010001;
 use Carp;
@@ -52,7 +52,7 @@ has border_style => (
         my ($self, $val) = @_;
         $self->{border_style_obj} =
             Module::Load::Util::instantiate_class_with_optional_args(
-                {ns_prefix=>'BorderStyle'}, $val);
+                {ns_prefixes=>['BorderStyle::Text::ANSITable', 'BorderStyle', 'BorderStyle::Text::ANSITable::OldCompat']}, $val);
     },
 );
 
@@ -63,7 +63,7 @@ has color_theme => (
         my ($self, $val) = @_;
         $self->{color_theme_obj} =
             Module::Load::Util::instantiate_class_with_optional_args(
-                {ns_prefix=>'ColorTheme'}, $val);
+                {ns_prefixes=>['ColorTheme::Text::ANSITable', 'ColorTheme', 'ColorTheme::Text::ANSITable::OldCompat']}, $val);
     },
 );
 
@@ -72,6 +72,11 @@ has columns => (
     default => sub { [] },
     trigger => sub {
         my $self = shift;
+
+        # check that column names are unique
+        my %seen;
+        for (@{$_[0]}) { die "Duplicate column name '$_'" if $seen{$_}++ }
+
         $self->{_columns_set}++;
     },
 );
@@ -282,10 +287,10 @@ sub BUILD {
         } elsif ($self->use_color) {
             my $bg = $self->detect_terminal->{default_bgcolor} // '';
             if ($self->color_depth >= 2**24) {
-                $ct = 'Text::ANSITable::Standard::Gradation' .
+                $ct = 'Standard::Gradation' .
                     ($bg eq 'ffffff' ? 'WhiteBG' : '');
             } else {
-                $ct = 'Text::ANSITable::Standard::NoGradation' .
+                $ct = 'Standard::NoGradation' .
                     ($bg eq 'ffffff' ? 'WhiteBG' : '');;
             }
         } else {
@@ -1715,7 +1720,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.602 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2021-02-19.
+This document describes version 0.603 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2021-08-08.
 
 =head1 SYNOPSIS
 
@@ -1729,7 +1734,7 @@ This document describes version 0.602 of Text::ANSITable (from Perl distribution
 
  # set styles
  $t->border_style('UTF8::SingleLineBold');  # if not, a nice default is picked
- $t->color_theme('Text::ANSITable::Standard::NoGradation');  # if not, a nice default is picked
+ $t->color_theme('Standard::NoGradation');  # if not, a nice default is picked
 
  # fill data
  $t->columns(["name"       , "color" , "price"]);
@@ -1869,13 +1874,13 @@ arguments:
  # during construction
  my $t = Text::ANSITable->new(
      ...
-     color_theme => "Text::ANSITable::Standard::NoGradation",
+     color_theme => "Standard::NoGradation",
      ...
  );
 
  # after the object is constructed
- $t->color_theme("Text::ANSITable::Standard::NoGradation");
- $t->color_theme(["Lens::Darken", {theme=>"Text::ANSITable::Standard::NoGradation"}]);
+ $t->color_theme("Standard::NoGradation");
+ $t->color_theme(["Lens::Darken", {theme=>"Standard::NoGradation"}]);
 
 If no color theme is selected explicitly, a nice default will be chosen. You can
 also set the C<ANSITABLE_COLOR_THEME> environment variable to set the default.
@@ -2225,7 +2230,9 @@ examples.
 
 =head1 ATTRIBUTES
 
-=head2 columns => ARRAY OF STR
+=head2 columns
+
+Array of str. Must be unique.
 
 Store column names. Note that when drawing, you can omit some columns, reorder
 them, or display some more than once (see C<column_filter> attribute).
@@ -2315,11 +2322,19 @@ disable wide-character support here.
 
 =head2 border_style => STR
 
-Border style name to use.
+Border style name to use. This is a module name in the
+C<BorderStyle::Text::ANSITable::*>, C<BorderStyle::*>, or
+C<BorderStyle::Text::ANSITable::OldCompat::*> namespace, without the prefix.
+See the L<BorderStyle> specification on how to create a new border style.
 
 =head2 color_theme => STR
 
-Color theme name to use.
+Color theme name to use. This is a module name in the
+C<ColorTheme::Text::ANSITable::*>, C<ColorTheme::*>, or
+C<ColorTheme::Text::ANSITable::OldCompat::*> namespace, without the prefix. See
+the L<ColorTheme> and an example existing color theme module like
+L<ColorTheme::Text::ANSITable::Standard::Gradation> specification on how to
+create a new border style.
 
 =head2 show_header => BOOL (default: 1)
 
@@ -2988,7 +3003,7 @@ Source repository is at L<https://github.com/perlancar/perl-Text-ANSITable>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Text-ANSITable/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-ANSITable>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -3043,9 +3058,25 @@ Unix command B<column> (e.g. C<column -t>).
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Mario Zieschang Steven Haryanto
+
+=over 4
+
+=item *
+
+Mario Zieschang <mario@zieschang.info>
+
+=item *
+
+Steven Haryanto <sharyanto@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
